app/soc/models/group.py
changeset 1085 0afbdd0905ef
parent 1060 eb6231138307
child 1307 091a21cf3627
--- a/app/soc/models/group.py	Fri Jan 30 17:23:19 2009 +0000
+++ b/app/soc/models/group.py	Fri Jan 30 17:38:28 2009 +0000
@@ -166,11 +166,11 @@
       verbose_name=ugettext('Shipping Country/Territory'),
       choices=countries.COUNTRIES_AND_TERRITORIES)
 
   #: Required property showing the current state of the group
   #: new: the group has not been active yet
   #: active: the group is active
   #: inactive: used to mark a group as read-only
   #: invalid: the group has been marked as removed
-  state = db.StringProperty(required=True, default='new',
+  status = db.StringProperty(required=True, default='new',
       choices=['new', 'active', 'inactive', 'invalid'])
@@ -166,11 +166,11 @@
       choices=countries.COUNTRIES_AND_TERRITORIES)
 
-  #: Required property showing the current state of the group
+  #: Required property showing the current status of the group
   #: new: the group has not been active yet
   #: active: the group is active